from ..Region.Region import Region


class IMARegion:
    """A IMARegion is an object used to define material instance name volume fractions for the
    MaterialAssignment predefined field.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].predefinedFields[name].assignmentList
    """

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the sub-region of the selected part instance to which the
    #: volume fractions will be applied.
    region: Region = Region()

    #: A tuple of Floats specifying the volume fractions, per material instance name. The
    #: length of the tuple corresponds to the number of material instance names, as established
    #: by the assigned Eulerian section.
    fractionList: float = None



from abaqusConstants import *
from .Area import Area
from .TextStyle import TextStyle


class Title:
    """The Title object is used to store the display attributes of the XYPlot title. An Title
    object is automatically created when creating a XYPlot object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultPlot.title
            session.xyPlots[name].title
    """

    #: A Boolean specifying whether to show the default title. The default value is OFF.
    useDefault: Boolean = OFF

    #: An :py:class:`~abaqus.XY.Area.Area` object specifying the area of the title.
    area: Area = Area()

    #: A String specifying the text to appear as a title. By default the title is set to the
    #: XYPlot object name. The default value is an empty string.
    text: str = ""

    #: A :py:class:`~abaqus.XY.TextStyle.TextStyle` object specifying the text properties used to display the legend title.
    titleStyle: TextStyle = TextStyle()

    def setValues(
        self,
        title: "Title",
        text: str = "",
        area: Area = None, 
        useDefault: Boolean = OFF,
        titleStyle: TextStyle = None, 
    ):
        """This method modifies the Title object.

        Parameters
        ----------
        title
            A :py:class:`~abaqus.XY.Title.Title` object from which attributes are to be copied.
        text
            A String specifying the text to appear as a title. By default the title is set to the
            XYPlot object name. The default value is an empty string.
        area
            An :py:class:`~abaqus.XY.Area.Area` object specifying the area of the title.
        useDefault
            A Boolean specifying whether to show the default title. The default value is OFF.
        titleStyle
            A :py:class:`~abaqus.XY.TextStyle.TextStyle` object specifying the text properties used to display the legend title.
        """
        pass



from abaqusConstants import *


class FailStrain:
    r"""The FailStrain object defines parameters for strain-based failure measures.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].elastic.failStrain
            import odbMaterial
            session.odbs[name].materials[name].elastic.failStrain

        The table data for this object are:
        
        - Tensile strain limit in fiber direction, :math:`X_{\varepsilon t}`.
        - Compressive strain limit in fiber direction, :math:`X_{\varepsilon c}`.
        - Tensile strain limit in transverse direction, :math:`Y_{\varepsilon t}`,
        - Compressive strain limit in transverse direction, :math:`Y_{\varepsilon c}`.
        - Shear strain limit in the :math:`X - Y` plane, :math:`S_{\varepsilon}`.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - FAIL STRAIN
    """

    def __init__(
        self, table: tuple, temperatureDependency: Boolean = OFF, dependencies: int = 0
    ):
        """This method creates a FailStrain object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].elastic.FailStrain
                session.odbs[name].materials[name].elastic.FailStrain

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        FailStrain
            A :py:class:`~abaqus.Material.Elastic.Linear.FailStrain.FailStrain` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the FailStrain object.

        Raises
        ------
        RangeError
        """
        pass
